@@ -1,5 +1,5 @@
 #
-# $Id: Generate.pm,v 14a5b315905e 2015/01/08 07:00:53 gomor $
+# $Id: Generate.pm,v f9542919cc81 2015/02/21 10:40:01 gomor $
 #
 # address::generate Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 14a5b315905e $',
+      revision => '$Revision: f9542919cc81 $',
       tags => [ qw(unstable address ipv4 routable reserved) ],
       attributes => {
          datadir => [ qw(directory) ],
@@ -31,9 +31,9 @@ sub brik_properties {
       require_modules => {
          'List::Util' => [ 'shuffle' ],
       },
-      require_binaries => {
-         'ulimit' => [ ],
-      },
+      #require_binaries => {
+         #'ulimit' => [ ],   # It is built-in
+      #},
    };
 }
 
