@@ -1,5 +1,5 @@
 #
-# $Id: Splunk.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Splunk.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
 #
 # api::splunk Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
+      revision => '$Revision: 1cb13feea4e0 $',
       tags => [ qw(unstable rest api splunk) ],
       attributes => {
          output_mode => [ qw(json|xml) ],
@@ -53,7 +53,7 @@ sub apps_local {
    my $response = $self->get($uri)
       or return $self->log->error("apps_local: get failed");
 
-   my $string_json = Metabrik::String::Json->new_from_brik($self);
+   my $string_json = Metabrik::String::Json->new_from_brik($self) or return;
 
    return $string_json->decode($response->{body});
 }
