@@ -1,5 +1,5 @@
 #
-# $Id: Www.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Www.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
 #
 # client::www Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
+      revision => '$Revision: 1cb13feea4e0 $',
       tags => [ qw(unstable browser http client www javascript screenshot) ],
       attributes => {
          uri => [ qw(uri) ],
@@ -759,7 +759,7 @@ sub screenshot {
    my $data = $mech->content_as_png
       or return $self->log->error("screenshot: content_as_png failed");
 
-   my $write = Metabrik::File::Write->new_from_brik($self);
+   my $write = Metabrik::File::Write->new_from_brik($self) or return;
    $write->encoding('ascii');
    $write->overwrite(1);
    $write->append(0);
