@@ -1,5 +1,5 @@
 #
-# $Id: Video.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Video.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
 #
 # convert::video Brik
 #
@@ -7,31 +7,26 @@ package Metabrik::Convert::Video;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 1db92d72d9a2 $',
       tags => [ qw(unstable convert avi jpg) ],
       attributes => {
+         datadir => [ qw(directory) ],
          input => [ qw(file) ],
          output_pattern => [ qw(file_pattern) ],
-         output_directory => [ qw(directory) ],
+      },
+      attributes_default => {
+         input => 'VIDEO.MP4',
+         output_pattern => 'image_%04d.jpg',
       },
       commands => {
          to_jpg => [ ],
       },
-   };
-}
-
-sub brik_use_properties {
-   my $self = shift;
-
-   return {
-      attributes_default => {
-         input => 'VIDEO.MP4',
-         output_pattern => 'image_%04d.jpg',
-         output_directory => $self->global->datadir,
+      require_binaries => {
+         'ffmpeg' => [ ],
       },
    };
 }
@@ -40,7 +35,7 @@ sub to_jpg {
    my $self = shift;
 
    my $input = $self->input;
-   my $output_directory = $self->output_directory;
+   my $datadir = $self->datadir;
    my $output_pattern = $self->output_pattern;
 
    if (! -f $input) {
@@ -49,10 +44,9 @@ sub to_jpg {
 
    # This program is only provided for compatibility and will be removed in a future release.
    # Please use avconv instead.
-   my $cmd = "ffmpeg -i $input $output_directory/".$output_pattern;
-   system("$cmd");
+   my $cmd = "ffmpeg -i $input $datadir/".$output_pattern;
 
-   return 1;
+   return $self->system($cmd);
 }
 
 1;
