@@ -1,5 +1,5 @@
 #
-# $Id: Text.pm,v 297f479a9ee8 2015/02/11 06:55:12 gomor $
+# $Id: Text.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
 #
 # file::text Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::File::Write);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 297f479a9ee8 $',
+      revision => '$Revision: 1cb13feea4e0 $',
       tags => [ qw(unstable file text read write) ],
       attributes => {
          input => [ qw(file) ],
@@ -53,7 +53,7 @@ sub read {
       return $self->log->error($self->brik_help_set('input'));
    }
 
-   my $read = Metabrik::File::Read->new_from_brik($self);
+   my $read = Metabrik::File::Read->new_from_brik($self) or return;
    $read->input($input);
    $read->encoding($self->encoding);
    $read->as_array($self->as_array);
