@@ -1,5 +1,5 @@
 #
-# $Id: Xml.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Xml.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
 #
 # file::xml Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::File::Read);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 1db92d72d9a2 $',
       tags => [ qw(unstable xml file) ],
       attributes => {
          input => [ qw(file) ],
@@ -58,7 +58,7 @@ sub read {
    my $data = $self->readall or return $self->log->error("read: readall failed");
    $self->close;
 
-   my $xml = Metabrik::String::Xml->new_from_brik($self);
+   my $xml = Metabrik::String::Xml->new_from_brik($self) or return;
    my $decode = $xml->decode($data) or return $self->log->error("read: decode failed");
 
    return $decode;
@@ -74,10 +74,10 @@ sub write {
       return $self->log->error($self->brik_help_run('write'));
    }
 
-   my $xml = Metabrik::String::Xml->new_from_brik($self);
+   my $xml = Metabrik::String::Xml->new_from_brik($self) or return;
    my $data = $xml->encode($xml_hash) or return $self->log->error("write: encode failed");
 
-   my $write = Metabrik::File::Write->new_from_brik($self);
+   my $write = Metabrik::File::Write->new_from_brik($self) or return;
    $write->open($output) or return $self->log->error("write: open failed");
    $write->write($data) or return $self->log->error("write: write failed");
    $write->close;
