@@ -1,5 +1,5 @@
 #
-# $Id: Countrycode.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Countrycode.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
 #
 # iana::countrycode Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Client::Www);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
+      revision => '$Revision: 1cb13feea4e0 $',
       tags => [ qw(unstable iana countrycode cc) ],
       attributes => {
          datadir => [ qw(datadir) ],
@@ -109,7 +109,7 @@ sub save {
 
    my $datadir = $self->datadir;
 
-   my $file_csv = Metabrik::File::Csv->new_from_brik($self);
+   my $file_csv = Metabrik::File::Csv->new_from_brik($self) or return;
    $file_csv->overwrite(1);
    $file_csv->encoding('utf8');
 
@@ -131,7 +131,7 @@ sub load {
 
    my $datadir = $self->datadir;
 
-   my $file_csv = Metabrik::File::Csv->new_from_brik($self);
+   my $file_csv = Metabrik::File::Csv->new_from_brik($self) or return;
    $file_csv->first_line_is_header(1);
 
    my $csv = $file_csv->read($datadir.'/'.$input);
