@@ -1,5 +1,5 @@
 #
-# $Id: Dual.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Dual.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
 #
 # log::dual Brik
 #
@@ -11,29 +11,20 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable) ],
-      author => 'GomoR <GomoR[at]metabrik.org>',
-      license => 'http://opensource.org/licenses/BSD-3-Clause',
+      revision => '$Revision: 1db92d72d9a2 $',
+      tags => [ qw(log) ],
       attributes => {
          level => [ qw(0|1|2|3) ],
-         output => [ qw(file) ],
-         time_prefix => [ qw(0|1) ],
-         text_prefix => [ qw(0|1) ],
+         output_file => [ qw(file) ],
          _fd => [ qw(file_descriptor) ],
       },
-      attributes_default => {
-         time_prefix => 0,
-         text_prefix => 0,
-         output => '/tmp/dual.log',
-      },
       commands => {
-         info => [ qw(string caller|OPTIONAL) ],
-         verbose => [ qw(string caller|OPTIONAL) ],
-         warning => [ qw(string caller|OPTIONAL) ],
-         error => [ qw(string caller|OPTIONAL) ],
-         fatal => [ qw(string caller|OPTIONAL) ],
-         debug => [ qw(string caller|OPTIONAL) ],
+         info => [ qw(string) ],
+         verbose => [ qw(string) ],
+         warning => [ qw(string) ],
+         error => [ qw(string) ],
+         fatal => [ qw(string) ],
+         debug => [ qw(string) ],
       },
       require_modules => {
          'Term::ANSIColor' => [ ],
@@ -48,6 +39,7 @@ sub brik_use_properties {
       attributes_default => {
          debug => $self->log->debug,
          level => $self->log->level,
+         output_file => $self->global->output,
       },
    };
 }
@@ -73,9 +65,11 @@ sub brik_preinit {
 sub brik_init {
    my $self = shift;
 
-   my $output = $self->output;
-   open(my $fd, '>', $output)
-      or return $self->log->error("brik_init: can't open output file [$output]: $!");
+   print "DEBUG log::dual brik_init\n";
+
+   my $output_file = $self->output_file;
+   open(my $fd, '>', $output_file)
+      or return $self->log->error("brik_init: can't open output file [$output_file]: $!");
 
    # Makes the file handle unbuffered
    my $current = select;
@@ -94,18 +88,16 @@ sub _msg {
 
    $msg ||= 'undef';
 
-   $brik =~ s/^metabrik:://i;
+   $brik =~ s/^metabrik::brik:://i;
 
    return lc($brik).": $msg\n";
 }
 
 sub warning {
    my $self = shift;
-   my ($msg, $caller) = @_;
+   my ($msg) = @_;
 
-   my $prefix = $self->text_prefix ? "WARN " : "[!]";
-   my $time = $self->time_prefix ? localtime()." " : " ";
-   my $buffer = $time."$prefix ".$self->_msg(($caller) ||= caller(), $msg);
+   my $buffer = "[!] ".$self->_msg(my ($caller) = caller(), $msg);
 
    my $fd = $self->_fd;
 
@@ -117,11 +109,9 @@ sub warning {
 
 sub error {
    my $self = shift;
-   my ($msg, $caller) = @_;
+   my ($msg) = @_;
 
-   my $prefix = $self->text_prefix ? "ERROR" : "[-]";
-   my $time = $self->time_prefix ? localtime()." " : " ";
-   my $buffer = $time."$prefix ".$self->_msg(($caller) ||= caller(), $msg);
+   my $buffer = "[-] ".$self->_msg(my ($caller) = caller(), $msg);
 
    my $fd = $self->_fd;
 
@@ -135,11 +125,9 @@ sub error {
 
 sub fatal {
    my $self = shift;
-   my ($msg, $caller) = @_;
+   my ($msg) = @_;
 
-   my $prefix = $self->text_prefix ? "FATAL" : "[F]";
-   my $time = $self->time_prefix ? localtime()." " : " ";
-   my $buffer = $time."$prefix ".$self->_msg(($caller) ||= caller(), $msg);
+   my $buffer = "[F] ".$self->_msg(my ($caller) = caller(), $msg);
 
    my $fd = $self->_fd;
 
@@ -149,15 +137,13 @@ sub fatal {
 
 sub info {
    my $self = shift;
-   my ($msg, $caller) = @_;
+   my ($msg) = @_;
 
-   return 1 unless $self->level > 0;
+   return 0 unless $self->level > 0;
 
    $msg ||= 'undef';
 
-   my $prefix = $self->text_prefix ? "INFO " : "[+]";
-   my $time = $self->time_prefix ? localtime()." " : " ";
-   my $buffer = $time."$prefix $msg\n";
+   my $buffer = "[+] $msg\n";
 
    my $fd = $self->_fd;
 
@@ -169,13 +155,11 @@ sub info {
 
 sub verbose {
    my $self = shift;
-   my ($msg, $caller) = @_;
+   my ($msg) = @_;
 
    return 1 unless $self->level > 1;
 
-   my $prefix = $self->text_prefix ? "VERB " : "[*]";
-   my $time = $self->time_prefix ? localtime()." " : " ";
-   my $buffer = $time."$prefix ".$self->_msg(($caller) ||= caller(), $msg);
+   my $buffer = "[*] ".$self->_msg(my ($caller) = caller(), $msg);
 
    my $fd = $self->_fd;
 
@@ -187,7 +171,7 @@ sub verbose {
 
 sub debug {
    my $self = shift;
-   my ($msg, $caller) = @_;
+   my ($msg) = @_;
 
    # We have a conflict between the method and the accessor,
    # we have to identify which one is accessed.
@@ -204,9 +188,7 @@ sub debug {
       else {
          return 1 unless $self->level > 2;
 
-         my $prefix = $self->text_prefix ? "DEBUG" : "[D]";
-         my $time = $self->time_prefix ? localtime()." " : " ";
-         my $buffer = $time."$prefix ".$self->_msg(($caller) ||= caller(), $msg);
+         my $buffer = "[D] ".$self->_msg(my ($caller) = caller(), $msg);
 
          my $fd = $self->_fd;
 
@@ -240,7 +222,7 @@ Metabrik::Log::Dual - log::dual Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
