@@ -1,5 +1,5 @@
 #
-# $Id: Arpdiscover.pm,v 1f774a18593c 2015/02/08 16:21:47 gomor $
+# $Id: Arpdiscover.pm,v 1d19720513f5 2015/03/08 11:41:04 gomor $
 #
 package Metabrik::Network::Arpdiscover;
 use strict;
@@ -11,7 +11,7 @@ use Net::Frame::Layer::ARP qw(:consts);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1f774a18593c $',
+      revision => '$Revision: 1d19720513f5 $',
       tags => [ qw(unstable arp scan discover) ],
       attributes => {
          try => [ qw(try_count) ],
@@ -60,6 +60,10 @@ sub scan {
    my $self = shift;
    my ($subnet) = @_;
 
+   if ($< != 0) {
+      return $self->log->error("scan: must be root to run");
+   }
+
    my $network_arp = Metabrik::Network::Arp->new_from_brik_init($self) or return;
    my $network_address = Metabrik::Network::Address->new_from_brik_init($self) or return;
 
