@@ -1,5 +1,5 @@
 #
-# $Id: Read.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Read.pm,v 1d19720513f5 2015/03/08 11:41:04 gomor $
 #
 # network::read Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
+      revision => '$Revision: 1d19720513f5 $',
       tags => [ qw(unstable network read ethernet ip raw socket) ],
       attributes => {
          device => [ qw(device) ],
@@ -60,6 +60,10 @@ sub open {
    my $self = shift;
    my ($layer, $arg2, $arg3) = @_;
 
+   if ($< != 0) {
+      return $self->log->error("open: must be root to run");
+   }
+
    $layer ||= 2;
 
    my $family = $self->family eq 'ipv6' ? 'ip6' : 'ip';
