@@ -1,5 +1,5 @@
 #
-# $Id: Dns.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Dns.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
 #
 # server::dns Brik
 #
@@ -11,9 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: 1db92d72d9a2 $',
       tags => [ qw(unstable server dns) ],
       attributes => {
+         datadir => [ qw(datadir) ],
          hostname => [ qw(listen_hostname) ],
          port => [ qw(listen_port) ],
          a => [ qw(a_hash) ],
@@ -30,6 +31,7 @@ sub brik_properties {
          hostname => '127.0.0.1',
          port => 2053,
          recursive_mode => 1,
+         cache_file => 'cache.db',
       },
       commands => {
          start => [ qw(listen_hostname|OPTIONAL listen_port|OPTIONAL) ],
@@ -40,32 +42,16 @@ sub brik_properties {
    };
 }
 
-sub brik_use_properties {
-   my $self = shift;
-
-   return {
-      attributes_default => {
-         cache_file => $self->global->datadir.'/dns/cache.db',
-      },
-   };
-}
-
 sub brik_init {
    my $self = shift;
 
-   my $dns_directory = $self->global->datadir.'/dns';
-   if (! -d $dns_directory) {
-      mkdir($dns_directory)
-         or return $self->log->error("brik_init: cannot create directory");
-   }
-
    $SIG{INT} = sub {
       $self->log->verbose("brik_init: INT caught, exiting.");
       $self->shell->run_exit; # So history will be correctly saved.
       exit(1);
    };
 
-   return $self->SUPER::brik_init;
+   return $self->SUPER::brik_init(@_);
 }
 
 sub start {
@@ -124,7 +110,7 @@ sub start {
          expire => '1d',             # expire time of cache
          init => 1,                  # clear cache at startup
          unlink => 1,                # destroy cache on exit
-         file => $self->cache_file,  # cache
+         file => $self->datadir.'/'.$self->cache_file,  # cache
       },
       SERVER => {
          address => $hostname,
