@@ -1,5 +1,5 @@
 #
-# $Id: Screenshot.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
+# $Id: Screenshot.pm,v e19c00b0d9d6 2015/02/21 10:44:32 gomor $
 #
 # xorg::screenshot Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: eff9afda3723 $',
+      revision => '$Revision: e19c00b0d9d6 $',
       tags => [ qw(unstable screenshot) ],
       attributes => {
          output => [ qw(file) ],
@@ -22,6 +22,7 @@ sub brik_properties {
       commands => {
          active_window => [ qw(output_file|OPTIONAL) ],
          full_screen => [ qw(output_file|OPTIONAL) ],
+         select_window => [ qw(output_file|OPTIONAL) ],
       },
       require_binaries => {
          'scrot' => [ ],
@@ -57,6 +58,20 @@ sub full_screen {
    return $output;
 }
 
+sub select_window {
+   my $self = shift;
+   my ($output) = @_;
+
+   $output ||= $self->output;
+
+   $self->log->verbose("select_window: saving to file [$output]");
+
+   my $cmd = "scrot --select --border $output";
+   $self->system($cmd);
+
+   return $output;
+}
+
 1;
 
 __END__
